(* x2164)(* x__2132__auto__ y__2133__auto__)(* x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of *
A primitive macro version of `*`
(+ x2148)(+ x__2132__auto__ y__2133__auto__)(+ x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of +
A primitive macro version of `+`
(- x2154)(- x__2132__auto__ y__2133__auto__)(- x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of -
A primitive macro version of `-`
(/ x2170)(/ x__2132__auto__ y__2133__auto__)(/ x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of /
A primitive macro version of `/`
(< x2238)(< x__2140__auto__ y__2141__auto__)(< x__2140__auto__ y__2141__auto__ & rest__2142__auto__)A primitive macro version of <
A primitive macro version of `<`
(<= x2246)(<= x__2140__auto__ y__2141__auto__)(<= x__2140__auto__ y__2141__auto__ & rest__2142__auto__)A primitive macro version of <=
A primitive macro version of `<=`
(== x2262)(== x__2140__auto__ y__2141__auto__)(== x__2140__auto__ y__2141__auto__ & rest__2142__auto__)A primitive macro version of ==
A primitive macro version of `==`
(> x2230)(> x__2140__auto__ y__2141__auto__)(> x__2140__auto__ y__2141__auto__ & rest__2142__auto__)A primitive macro version of >
A primitive macro version of `>`
(>= x2254)(>= x__2140__auto__ y__2141__auto__)(>= x__2140__auto__ y__2141__auto__ & rest__2142__auto__)A primitive macro version of >=
A primitive macro version of `>=`
(>>> n bits)An alias for bit-unsigned-shift-right.
An alias for `bit-unsigned-shift-right`.
(bit-and x2182)(bit-and x__2132__auto__ y__2133__auto__)(bit-and x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of bit-and
A primitive macro version of `bit-and`
(bit-not x)A primitive macro version of bit-not.
A primitive macro version of `bit-not`.
(bit-or x2188)(bit-or x__2132__auto__ y__2133__auto__)(bit-or x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of bit-or
A primitive macro version of `bit-or`
(bit-shift-left n bits)A primitive macro version of bit-shift-left.
A primitive macro version of `bit-shift-left`.
(bit-shift-right n bits)A primitive macro version of bit-shift-right.
A primitive macro version of `bit-shift-right`.
(bit-xor x2194)(bit-xor x__2132__auto__ y__2133__auto__)(bit-xor x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of bit-xor
A primitive macro version of `bit-xor`
(bool-and x2200)(bool-and x__2132__auto__ y__2133__auto__)(bool-and x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of bool-and
A primitive macro version of `bool-and`
(bool-not x)A primitive macro version of not.
A primitive macro version of `not`.
(bool-or x2206)(bool-or x__2132__auto__ y__2133__auto__)(bool-or x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of bool-or
A primitive macro version of `bool-or`
(bool-xor x2212)(bool-xor x__2132__auto__ y__2133__auto__)(bool-xor x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of bool-xor
A primitive macro version of `bool-xor`
(byte x)Truncates a number to a byte, will not check for overflow.
Truncates a number to a byte, will not check for overflow.
(byte->ubyte x)Converts a byte to an unsigned byte.
Converts a byte to an unsigned byte.
(dec x)A primitive macro version of dec.
A primitive macro version of `dec`.
(div x2176)(div x__2132__auto__ y__2133__auto__)(div x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of div
A primitive macro version of `div`
(double->long x)Converts a double to a long.
Converts a double to a long.
(false? x)A primitive macro version of false?.
A primitive macro version of `false?`.
(float x)Truncates a number to a float, will not check for overflow.
Truncates a number to a float, will not check for overflow.
(float->int x)Converts a float to an integer.
Converts a float to an integer.
(inc x)A primitive macro version of inc.
A primitive macro version of `inc`.
(int x)Truncates a number to an int, will not check for overflow.
Truncates a number to an int, will not check for overflow.
(int->float x)Converts an integer to a float.
Converts an integer to a float.
(int->uint x)Converts an integer to an unsigned integer.
Converts an integer to an unsigned integer.
(long->double x)Converts a long to a double.
Converts a long to a double.
(long->ulong x)Converts a long to an unsigned long.
Converts a long to an unsigned long.
(max x2224)(max x__2132__auto__ y__2133__auto__)(max x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of max
A primitive macro version of `max`
(min x2218)(min x__2132__auto__ y__2133__auto__)(min x__2132__auto__ y__2133__auto__ & rest__2134__auto__)A primitive macro version of min
A primitive macro version of `min`
(not== x2270)(not== x__2140__auto__ y__2141__auto__)(not== x__2140__auto__ y__2141__auto__ & rest__2142__auto__)A primitive macro complement of ==
A primitive macro complement of `==`
(rem n div)A primitive macro version of rem.
A primitive macro version of `rem`.
(reverse-double x)Inverts the endianness of a double.
Inverts the endianness of a double.
(reverse-float x)Inverts the endianness of a float.
Inverts the endianness of a float.
(reverse-int x)Inverts the endianness of an int.
Inverts the endianness of an int.
(reverse-long x)Inverts the endianness of a long.
Inverts the endianness of a long.
(reverse-short x)Inverts the endianness of a short.
Inverts the endianness of a short.
(short x)Truncates a number to a short, will not check for overflow.
Truncates a number to a short, will not check for overflow.
(short->ushort x)Converts a short to an unsigned short.
Converts a short to an unsigned short.
(true? x)A primitive macro version of true?.
A primitive macro version of `true?`.
(ubyte->byte x)Converts an unsigned byte to a byte.
Converts an unsigned byte to a byte.
(uint->int x)Converts an unsigned integer to an integer.
Converts an unsigned integer to an integer.
(ulong->long x)Converts an unsigned long to a long.
Converts an unsigned long to a long.
(unsigned-bit-shift-right n bits)A primitive macro which performs an unsigned right bit-shift.
A primitive macro which performs an unsigned right bit-shift.
(unuse-primitive-operators)Undoes the work of use-primitive-operators. This is idempotent.
Undoes the work of `use-primitive-operators`. This is idempotent.
(use-primitive-operators)Replaces Clojure's arithmetic and number coercion functions with primitive equivalents. These are defined as macros, so they cannot be used as higher-order functions. This is an idempotent operation..
Replaces Clojure's arithmetic and number coercion functions with primitive equivalents. These are defined as macros, so they cannot be used as higher-order functions. This is an idempotent operation..
(ushort->short x)Converts an unsigned short to a short.
Converts an unsigned short to a short.
(zero? x)A primitive macro version of zero?.
A primitive macro version of `zero?`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |